@@ -13,5 +13,4 @@
 #' }
 #' @references Lohr (1999). Sampling: Design and Analysis, Duxbury, p. TODO and
 #'   439.
-#' @export
-NULL
+"audit"
\ No newline at end of file
