@@ -8,5 +8,4 @@
 #' }
 #' @references Lohr (1999). Sampling: Design and Analysis, Duxbury, p. 230--234 and
 #'   441.
-#' @export
-NULL
+"htpop"
\ No newline at end of file
