@@ -23,5 +23,4 @@
 #'   Department of Justice 1991.
 #' @references Lohr (1999). Sampling: Design and Analysis, Duxbury, p. TODO and
 #'   443.
-#' @export
-NULL
+"ncvs"
\ No newline at end of file
