@@ -21,5 +21,4 @@
 #'   Report NMFS SSRF-716. Washington, D.C: Government Printing Office.
 #' @references Lohr (1999). Sampling: Design and Analysis, Duxbury, p. TODO and
 #'   443.
-#' @export
-NULL
+"nybight"
\ No newline at end of file
