@@ -24,5 +24,4 @@
 #' 
 #' Lohr (1999). Sampling: Design and Analysis, Duxbury, p. TODO and
 #'   446.
-#' @export
-NULL
+"teachers"
\ No newline at end of file
